@@ -1,12 +1,5 @@
-/* LICENSE BEGIN
-    This file is part of the SixtyFPS Project -- https://sixtyfps.io
-    Copyright (c) 2021 Olivier Goffart <olivier.goffart@sixtyfps.io>
-    Copyright (c) 2021 Simon Hausmann <simon.hausmann@sixtyfps.io>
-
-    SPDX-License-Identifier: GPL-3.0-only
-    This file is also available under commercial licensing terms.
-    Please contact info@sixtyfps.io for more information.
-LICENSE END */
+// Copyright © SixtyFPS GmbH <info@sixtyfps.io>
+// SPDX-License-Identifier: (GPL-3.0-only OR LicenseRef-SixtyFPS-commercial)
 
 use std::path::Path;
 
@@ -15,7 +8,7 @@ use lsp_types::{GotoDefinitionResponse, LocationLink, Range, Url};
 use sixtyfps_compilerlib::diagnostics::Spanned;
 use sixtyfps_compilerlib::expression_tree::Expression;
 use sixtyfps_compilerlib::langtype::Type;
-use sixtyfps_compilerlib::lookup::LookupObject;
+use sixtyfps_compilerlib::lookup::{LookupObject, LookupResult};
 use sixtyfps_compilerlib::parser::{syntax_nodes, SyntaxKind, SyntaxNode, SyntaxToken};
 
 pub fn goto_definition(
@@ -44,7 +37,7 @@ pub fn goto_definition(
                     if token.kind() != SyntaxKind::Identifier {
                         return None;
                     }
-                    let expr = crate::util::with_lookup_ctx(document_cache, node, |ctx| {
+                    let lr = crate::util::with_lookup_ctx(document_cache, node, |ctx| {
                         let mut it = n
                             .children_with_tokens()
                             .filter_map(|t| t.into_token())
@@ -53,20 +46,25 @@ pub fn goto_definition(
                         let first_str =
                             sixtyfps_compilerlib::parser::normalize_identifier(cur_tok.text());
                         let global = sixtyfps_compilerlib::lookup::global_lookup();
-                        let mut expr_it = global.lookup(ctx, &first_str)?.expression;
+                        let mut expr_it = global.lookup(ctx, &first_str)?;
                         while cur_tok.token != token.token {
                             cur_tok = it.next()?;
                             let str =
                                 sixtyfps_compilerlib::parser::normalize_identifier(cur_tok.text());
-                            expr_it = expr_it.lookup(ctx, &str)?.expression;
+                            expr_it = expr_it.lookup(ctx, &str)?;
                         }
                         Some(expr_it)
                     })?;
-                    let gn = match expr? {
-                        Expression::ElementReference(e) => {
-                            e.upgrade()?.borrow().node.clone()?.into()
-                        }
-                        Expression::CallbackReference(nr) | Expression::PropertyReference(nr) => {
+                    let gn = match lr? {
+                        LookupResult::Expression {
+                            expression: Expression::ElementReference(e),
+                            ..
+                        } => e.upgrade()?.borrow().node.clone()?.into(),
+                        LookupResult::Expression {
+                            expression:
+                                Expression::CallbackReference(nr) | Expression::PropertyReference(nr),
+                            ..
+                        } => {
                             let mut el = nr.element();
                             loop {
                                 if let Some(x) = el.borrow().property_declarations.get(nr.name()) {
