@@ -1,12 +1,5 @@
-/* LICENSE BEGIN
-    This file is part of the SixtyFPS Project -- https://sixtyfps.io
-    Copyright (c) 2021 Olivier Goffart <olivier.goffart@sixtyfps.io>
-    Copyright (c) 2021 Simon Hausmann <simon.hausmann@sixtyfps.io>
-
-    SPDX-License-Identifier: GPL-3.0-only
-    This file is also available under commercial licensing terms.
-    Please contact info@sixtyfps.io for more information.
-LICENSE END */
+// Copyright © SixtyFPS GmbH <info@sixtyfps.io>
+// SPDX-License-Identifier: (GPL-3.0-only OR LicenseRef-SixtyFPS-commercial)
 
 mod completion;
 mod goto;
@@ -16,7 +9,6 @@ mod semantic_tokens;
 mod util;
 
 use std::collections::HashMap;
-use structopt::StructOpt;
 
 use lsp_server::{Connection, Message, Request, RequestId, Response};
 use lsp_types::notification::{DidChangeTextDocument, DidOpenTextDocument, Notification};
@@ -39,25 +31,28 @@ use sixtyfps_compilerlib::typeloader::TypeLoader;
 use sixtyfps_compilerlib::typeregister::TypeRegister;
 use sixtyfps_compilerlib::CompilerConfiguration;
 
+use clap::Parser;
+
 type Error = Box<dyn std::error::Error>;
 
 const SHOW_PREVIEW_COMMAND: &str = "showPreview";
 
-#[derive(StructOpt, Clone)]
+#[derive(Clone, clap::Parser)]
 struct Cli {
-    #[structopt(
-        short = "I",
+    #[clap(
+        short = 'I',
         name = "Add include paths for the import statements",
-        number_of_values = 1
+        number_of_values = 1,
+        parse(from_os_str)
     )]
     include_paths: Vec<std::path::PathBuf>,
 
     /// The style name for the preview ('native', 'fluent' or 'ugly')
-    #[structopt(long, name = "style name", default_value)]
+    #[clap(long, name = "style name", default_value_t)]
     style: String,
 
     /// The backend used for the preview ('GL' or 'Qt')
-    #[structopt(long, name = "backend", default_value)]
+    #[clap(long, name = "backend", default_value_t)]
     backend: String,
 }
 
@@ -116,7 +111,7 @@ impl<'a> DocumentCache<'a> {
 }
 
 fn main() {
-    let args: Cli = Cli::from_args();
+    let args: Cli = Cli::parse();
     if !args.backend.is_empty() {
         std::env::set_var("SIXTYFPS_BACKEND", &args.backend);
     }
@@ -154,7 +149,7 @@ fn run_lsp_server() -> Result<(), Error> {
         }),
         definition_provider: Some(OneOf::Left(true)),
         text_document_sync: Some(TextDocumentSyncCapability::Kind(
-            lsp_types::TextDocumentSyncKind::Full,
+            lsp_types::TextDocumentSyncKind::FULL,
         )),
         code_action_provider: Some(CodeActionProviderCapability::Simple(true)),
         execute_command_provider: Some(ExecuteCommandOptions {
@@ -167,8 +162,8 @@ fn run_lsp_server() -> Result<(), Error> {
         semantic_tokens_provider: Some(
             SemanticTokensOptions {
                 legend: SemanticTokensLegend {
-                    token_types: semantic_tokens::LEGEND_TYPES.iter().cloned().collect(),
-                    token_modifiers: semantic_tokens::LEGEND_MODS.iter().cloned().collect(),
+                    token_types: semantic_tokens::LEGEND_TYPES.to_vec(),
+                    token_modifiers: semantic_tokens::LEGEND_MODS.to_vec(),
                 },
                 full: Some(SemanticTokensFullOptions::Bool(true)),
                 ..Default::default()
@@ -185,7 +180,7 @@ fn run_lsp_server() -> Result<(), Error> {
 }
 
 fn main_loop(connection: &Connection, params: serde_json::Value) -> Result<(), Error> {
-    let cli_args: Cli = Cli::from_args();
+    let cli_args: Cli = Cli::parse();
     let params: InitializeParams = serde_json::from_value(params).unwrap();
     let mut compiler_config =
         CompilerConfiguration::new(sixtyfps_compilerlib::generator::OutputFormat::Interpreter);
@@ -601,7 +596,7 @@ fn get_document_symbols(
                     make_range(c.root_element.borrow().node.as_ref()?)?,
                 ),
                 name: c.id.clone(),
-                kind: lsp_types::SymbolKind::Object,
+                kind: lsp_types::SymbolKind::OBJECT,
                 ..si.clone()
             })
         })
@@ -611,7 +606,7 @@ fn get_document_symbols(
         Type::Struct { name: Some(name), node: Some(node), .. } => Some(SymbolInformation {
             location: Location::new(uri.clone(), make_range(node.parent().as_ref()?)?),
             name: name.clone(),
-            kind: lsp_types::SymbolKind::Struct,
+            kind: lsp_types::SymbolKind::STRUCT,
             ..si.clone()
         }),
         _ => None,
